@@ -723,9 +723,13 @@ sunone_invitation_list_model_set_value (SunOneInvitationListModel *model, int co
 		key = g_strconcat (priv->calid, ":calendar", NULL);
 		wcap = sunone_connection_get_wcap (cnc, key);
 		g_free (key);
-		if (wcap)
-			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap), NULL,
-					icalcomponent_as_ical_string (clonecomp), CALOBJ_MOD_ALL, NULL, NULL);
+		if (wcap) {
+			char *string = icalcomponent_as_ical_string (clonecomp);
+
+			cal_backend_wcap_events_update_objects (E_CAL_BACKEND_SYNC (wcap),
+					NULL, string, CALOBJ_MOD_ALL, NULL, NULL);
+			g_free (string);
+		}
 		icalcomponent_free (clonecomp);
 	}
 }
